\name{StatSeasAtlTC}
\alias{StatSeasAtlTC}
\title{Compute estimate of seasonal mean of Atlantic hurricane activity}
\description{
Compute one of G. Villarini's statistically downscaled measure of mean Atlantic hurricane activity and its variance. The hurricane activity is estimated using seasonal averages of sea surface temperature anomalies over the tropical Atlantic (bounded by 10N-25N and 80W-20W) and the tropics at large (bounded by 30N-30S). The anomalies are for the JJASON season.\cr
The estimated seasonal average is either 1) number of hurricanes, 2) number of tropical cyclones with lifetime >=48h or 3) power dissipation index (PDI; in 10^11 m^3 s^{-2}).\cr
The statistical models used in this function are described in\cr
Villarini et al. (2010), Mon Wea Rev, 138, 2681-2705.\cr
Villarini et al. (2012), Mon Wea Rev, 140, 44-65.\cr
Villarini et al. (2012), J Clim, 25, 625-637.
}
\usage{
StatSeasAtlTC(atlano=NULL,tropano=NULL,hrvar='HR')
}
\arguments{
 \item{atlano}{
 Array of Atlantic sea surface temperature anomalies.  Must have the same dimension as tropano.
 }
 \item{tropano}{
 Array of tropical sea surface temperature anomalies.  Must have the same dimension as atlano.
 }
 \item{hrvar}{
 The seasonal average to be estimated. The options are either\cr 
 "HR" (hurricanes) \cr
 "TC" (tropical cyclones with lifetime >=48h) \cr
 "PDI" (power dissipation index) \cr
 }
}
\value{
     A list composed of two matrices:\cr
     1. a matrix (mean) with the seasonal average values of the desired quantity.\cr 
     2. a matrix (var) of the variance of that quantity.\cr
     The dimensions of the two matrices are the same as the dimensions of atlano/tropano.
}
\examples{
print("Hello")
} 
 \author{
  History:\cr
  0.1  -  2015-11  (Louis-Philippe Caron, \email{louis-philppe.caron@bsc.es})  -  Original code 
}
\keyword{datagen}